# Quantxt Theia Python client library


The official [Quantxt][quantxt] Python client library.

Theia is a fully managed document extraction software. User needs to first configure the fields that they want to extract. Theia guarantees correct extraction of data if the fields are configured properly. Fields can be embedded in plain text, within tables or within forms.

Theia can process documents in various formats including PDF, TIFF, PNG, JPEG, TSV, TXT and Ms Excel. Scanned documents are automatically detected and run through OCR before extraction. 


## Installation

### Requirements

- Python 3.6 or later


### Installation

```
pip install qtcurate
```

[quantxt]: http://quantxt.com

Refer to the [Samples](sample) for examples

[Official documentation](http://quantxt.com/pages/documentation.html)

Contact us at <support@quantxt.com> for API key or technical questions.
